import { systemUserInfoMenu } from "@/api/path/system.api";
import { systemRoutes } from "./router.system";
import { getLocalStorage, getParseLang } from '@/utils'
import { lang } from '@/settings/designSetting'
import { publicMenu } from './router.system.js'
const LAYOUT = () => import("@/components/Layout/Layout.vue");

const findPath = (data) => {
  if (data.children && data.children.length > 0) {
    return findPath(data.children[0]);
  } else {
    return data;
  }
};

// 生成路由
const comp = import.meta.glob("../views/**/index.vue");
const component = (view) => {
  return () => comp[`../${view}`]();
};



// 路由格式转化
const toRoutesJson = (data) => {
  const LANG =  getLocalStorage("LANG") || {lang}
  return data.map((item) => {
    const routeItem = {
      path: `/${item.path}`,
      name: item.path,
      meta: {
        title: getParseLang(item.name, LANG.lang),
        icon: item.icon,
      },
    };
    if (item.url && item.type == "2") {
      routeItem.component = component(item.url);
    }
    if (item.children && item.children.length > 0) {
      routeItem.children = toRoutesJson(item.children);
    }
    return routeItem;
  });
};

export const updateRouteByMenu = async (router, systemStore) => {
  if(!systemStore.getToken) {
    router.push({
      name: "login",
    })
    return
  }
  try {
    const { data: menuList } = await systemUserInfoMenu();
    systemStore.setStateValue({
      key: "menus",
      value: menuList || [],
      localStorage: true,
    });
    const pathHome = findPath(publicMenu[0]);
    const mainRoutes = toRoutesJson(menuList);
    const routes = {
      path: "/",
      name: "main",
      redirect: pathHome.path,
      component: LAYOUT,
      children: [...publicMenu,...mainRoutes],
    };
    router.options.routes = [routes, ...systemRoutes];
    await router.addRoute(routes);
  } catch(err) {
    console.log(err)
  }
};
